==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_kvmvm_list_deleted/main.tf <==
/*
Пример использования
Получение данных о списке удаленных compute (виртуальных машин)
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/
provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_kvmvm_list_deleted" "compute_list" {
  #фильтр по id виртуальной машины
  #опциональный параметр
  #тип - число
  #by_id = 100
 
  #фильтр по имени виртуальной машины
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - число
  #account_id = 100

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "some"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по имени extNet
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id extNet
  #опциональный параметр
  #тип - число
  #extnet_id = 100

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "output" {
  value = data.decort_kvmvm_list_deleted.compute_list
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_kvmvm_list_deleted/main.tf <==
/*
Пример использования
Получение данных о списке удаленных compute (виртуальных машин)
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/
provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_kvmvm_list_deleted" "compute_list" {
  #фильтр по id виртуальной машины
  #опциональный параметр
  #тип - число
  #by_id = 100
 
  #фильтр по имени виртуальной машины
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - число
  #account_id = 100

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "some"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по имени extNet
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id extNet
  #опциональный параметр
  #тип - число
  #extnet_id = 100

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "output" {
  value = data.decort_kvmvm_list_deleted.compute_list
}
